==> klayout-0.10.tar.gz: klayout-0.10/src/layDrawing.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/



#ifndef HDR_layDrawing
#define HDR_layDrawing

#include <vector>

#include <tlCollection.h>
#include <layViewOp.h>
#include <dbTrans.h>

namespace lay
{

class CellView;
class Drawings;
class Bitmap;

/**
 *  @brief The drawing interface
 *
 *  A "drawing" object implements functionality to draw objects
 *  from a cellview onto a set of bitmaps. 
 *  The object can control the appearance of the bitmaps.
 *  Basically, the object must implement these features:
 *
 *  1.) Allocate a number of bitmaps in the constructor using 
 *  the num_bitmaps parameter of the "Drawing" constructor.
 *
 *  2.) Implement a drawing function ("paint_on_bitmaps")
 *  that draws the given cellview onto the bitmaps provided.
 *  This method is called from the drawing thread and must not
 *  make use of members of the object or protect them with a 
 *  mutex. 
 *
 *  3.) Control the appearance of the bitmap planes using the 
 *  "set_view_ops" method.
 */

class Drawing
  : public tl::Collectable
{
public:
  /**
   *  @brief The constructor
   *  
   *  See above for a explanation of the parent-child relationship.
   */
  Drawing (unsigned int num_bitmaps, Drawings *drawings);

  /**
   *  @brief The destructor
   */
  virtual ~Drawing ();

  /**
   *  @brief Paint on the bitmaps provided (called by the drawing thread)
   *
   *  @param cellview The cellview to paint
   *  @param trans The transformation to use when painting
   *  @param bitmaps The bitmaps to paint on. The number is the same than
   *                 passed in the constructor.
   */
  virtual void paint_on_bitmaps (const lay::CellView &cellview, 
                                 const db::MagTrans &trans,
                                 const std::vector <lay::Bitmap *> &bitmaps)
  {
    // .. nothing yet ..
  }

  /**
   *  @brief Obtain the number of bitmaps allocated
   */
  unsigned int num_bitmaps () const
  {
    return m_num_bitmaps;
  }

  /**
   *  @brief Get the current appearance
   */
  const std::vector <lay::ViewOp> &get_view_ops () const
  {
    return m_view_ops;
  }

protected:
  /**
   *  @brief Control the appearance of the bitmaps
   */
  void set_view_ops (const std::vector <lay::ViewOp> &view_ops);

private:
  unsigned int m_num_bitmaps;
  Drawings *mp_drawings;
  std::vector <lay::ViewOp> m_view_ops;
};

/**
 *  @brief The collection of drawing objects
 */
class Drawings
  : public tl::Collection<lay::Drawing> 
{
public:
  /**
   *  @brief The constructor
   */
  Drawings ()
    : tl::Collection<lay::Drawing> ()
  {
    // .. nothing yet ..
  }

  /**
   *  @brief The destructor
   */
  virtual ~Drawings ()
  {
    // .. nothing yet ..
  }

  /**
   *  @brief Update the display establishing the appearance
   */
  virtual void update_drawings () = 0;
};

}

#endif

==> klayout-0.15.tar.gz: klayout-0.15/src/layDrawing.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/



#ifndef HDR_layDrawing
#define HDR_layDrawing

#include <vector>

#include <tlCollection.h>
#include <layViewOp.h>
#include <dbTrans.h>

namespace lay
{

class CellView;
class Drawings;
class Bitmap;

/**
 *  @brief The drawing interface
 *
 *  A "drawing" object implements functionality to draw objects
 *  from a cellview onto a set of bitmaps. 
 *  The object can control the appearance of the bitmaps.
 *  Basically, the object must implement these features:
 *
 *  1.) Allocate a number of bitmaps in the constructor using 
 *  the num_bitmaps parameter of the "Drawing" constructor.
 *
 *  2.) Implement a drawing function ("paint_cv_on_bitmaps")
 *  that draws the given cellview onto the bitmaps provided.
 *  This method is called from the drawing thread and must not
 *  make use of members of the object or protect them with a 
 *  mutex. It is also possible to implement "paint_on_bitmaps" 
 *  to draw without a cellview.
 *
 *  3.) Control the appearance of the bitmap planes using the 
 *  "set_view_ops" method.
 */

class Drawing
  : public tl::Collectable
{
public:
  /**
   *  @brief The constructor
   *  
   *  See above for a explanation of the parent-child relationship.
   */
  Drawing (unsigned int num_bitmaps, Drawings *drawings);

  /**
   *  @brief The destructor
   */
  virtual ~Drawing ();

  /**
   *  @brief Paint on the bitmaps provided (called by the drawing thread)
   *
   *  @param cellview The cellview to paint
   *  @param trans The transformation to use when painting
   *  @param bitmaps The bitmaps to paint on. The number is the same than
   *                 passed in the constructor.
   */
  virtual void paint_cv_on_bitmaps (const lay::CellView &cellview, 
                                    const db::CplxTrans &trans,
                                    const std::vector <lay::Bitmap *> &bitmaps)
  {
    // .. nothing yet ..
  }

  /**
   *  @brief Paint annotation shapes on the bitmaps provided (called by the drawing thread)
   *
   *  @param trans The transformation to use when painting
   *  @param bitmaps The bitmaps to paint on. The number is the same than
   *                 passed in the constructor.
   */
  virtual void paint_on_bitmaps (const db::CplxTrans &trans,
                                 const std::vector <lay::Bitmap *> &bitmaps)
  {
    // .. nothing yet ..
  }

  /**
   *  @brief Obtain the number of bitmaps allocated
   */
  unsigned int num_bitmaps () const
  {
    return m_num_bitmaps;
  }

  /**
   *  @brief Get the current appearance
   */
  const std::vector <lay::ViewOp> &get_view_ops () const
  {
    return m_view_ops;
  }

protected:
  /**
   *  @brief Control the appearance of the bitmaps
   */
  void set_view_ops (const std::vector <lay::ViewOp> &view_ops);

private:
  unsigned int m_num_bitmaps;
  Drawings *mp_drawings;
  std::vector <lay::ViewOp> m_view_ops;
};

/**
 *  @brief The collection of drawing objects
 */
class Drawings
  : public tl::Collection<lay::Drawing> 
{
public:
  /**
   *  @brief The constructor
   */
  Drawings ()
    : tl::Collection<lay::Drawing> ()
  {
    // .. nothing yet ..
  }

  /**
   *  @brief The destructor
   */
  virtual ~Drawings ()
  {
    // .. nothing yet ..
  }

  /**
   *  @brief Update the display establishing the appearance
   */
  virtual void update_drawings () = 0;
};

}

#endif
